Mem2Mem

Struct Mem2Mem 

pub struct Mem2Mem<'d, Dm>
where Dm: DriverMode,
{ pub rx: Mem2MemRx<'d, Dm>, pub tx: Mem2MemTx<'d, Dm>, }
Available on crate feature unstable only.
DMA Memory to Memory pseudo-Peripheral

This is a pseudo-peripheral that allows for memory to memory transfers. It is not a real peripheral, but a way to use the DMA engine for memory to memory transfers.

Fields

rx: Mem2MemRx<'d, Dm>

RX Half

tx: Mem2MemTx<'d, Dm>

TX Half

Implementations

Source

impl<'d> Mem2Mem<'d, Blocking>

pub fn new<CH>( channel: CH, peripheral: impl DmaEligiblePeripheral<CH::Erased>, ) -> Self
where CH: Mem2MemCapableChannel<'d>,

Create a new Mem2Mem instance.

pub unsafe fn new_unsafe<CH>(channel: CH, peripheral: DmaPeripheral) -> Self
where CH: Mem2MemCapableChannel<'d>,

Create a new Mem2Mem instance.

Safety

You must ensure that you’re not using DMA for the same peripheral and that you’re the only one using the peripheral. You must also ensure that the peripheral is compatible with the channel.

pub fn into_async(self) -> Mem2Mem<'d, Async>

Convert Mem2Mem to an async Mem2Mem.

Source

impl<'d> Mem2Mem<'d, Blocking>

pub fn with_descriptors( self, rx_descriptors: &'d mut [DmaDescriptor], tx_descriptors: &'d mut [DmaDescriptor], config: BurstConfig, ) -> Result<SimpleMem2Mem<'d, Blocking>, DmaError>

Shortcut to create a SimpleMem2Mem